import {Component, OnInit, ViewChild} from '@angular/core';
import {pageSize} from '../../app.constants';
import {WorkService} from '../work.service';
import {NzMessageService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {EventComponent} from './Event/event.component';
import {CommonService} from '../../shared/common/common.service';
import {SelectPersonComponent} from '../../modal/select-person/select-person.component';

@Component({
    selector: 'smart-work-handle',
    templateUrl: './work-handle.component.html',
    styles: []
})
export class WorkHandleComponent implements OnInit {
    @ViewChild('smartEvent') smartEvent: EventComponent;
    @ViewChild('smartSelectPerson') smartSelectPerson:SelectPersonComponent;

    timeFormat = 'yyyy-MM-dd';
    eventList;
    timeBegin;
    timeEnd;
    pageCount = pageSize;
    pageNum = 1;
    totalNum;

    obj = {
        pageCount: null,
        pageNum: null,
        searchStr: '',
        type: null,
        status: null,
        source: null,
        startTime: '',
        endTime: '',
    };

    //转派
    isVisiable= false;
    transforList = [];
    transforId;

    constructor(private workSer: WorkService, private message: NzMessageService,
                private router: Router, private commonSer: CommonService) {
    }

    ngOnInit() {
        this.getList();
    }

    getList() {
        const obj = {
            pageCount: this.pageCount,
            pageNum: this.pageNum,
            searchStr: this.obj.searchStr,
            type: this.obj.type,
            status: this.obj.status,
            source: this.obj.source,
            startTime: this.obj.startTime,
            endTime: this.obj.endTime,
        };
        this.workSer.find(obj).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.eventList = res.data.data;
                    this.totalNum = res.data.totalNum;
                } else {

                }
            }
        );
    }

    change(e) {
        this.pageNum = e;
        this.getList();
    }

    //查看详情
    lookEvent(item) {
        this.router.navigate(['app/main/handleDetail'], {
            queryParams: {
                eventId: item.id
            }
        });
    }

    //新增事件
    showAddModal() {
        this.smartEvent.showAddModal('新增事件');
    }

    //编辑事件
    showEditModal(item){
        this.smartEvent.showEditModal("编辑事件",item.id);
    }

    //删除事件
    deleteHandle(data) {
        const arr = {
            ids: []
        };
        arr.ids.push(data.id);
        this.commonSer.deleteThing('确定删除该事件', () => {
            this.workSer.deleteEvent(arr).subscribe(
                (res) => {
                    if (res.errCode == 10000) {
                        this.message.success('删除成功');
                        this.getList();
                    } else {
                        this.message.error(res.errMsg);
                    }
                }
            );
        });
    }

    //事件转派--start
    showTransfor(item){
        this.transforId = item.id;
        this.isVisiable = true;
    }

    //选择处理人弹窗
    selectPerson(){
        this.smartSelectPerson.showModal("选择转派人");
    }

    //选择转派人done
    getUser(e){
        const arr = [];
        e.forEach(res => {
            const data = {
                username: res.name,
                userId: res.id
            };
            arr.push(data);
        });
        this.transforList = arr;
    }

    //取消
    handleCancel(){
        this.isVisiable = false;
        this.transforList = [];
    }

    deletePerson(i){
        this.transforList.splice(i,1);
    }

    //确定
    handleOk(){
        const data = {
            id:this.transforId,
            operators:this.transforList
        };
        this.workSer.transfer(data).subscribe(
            (res)=>{
                if(res.errCode == 10000){
                    this.message.success("事件转派成功");
                    this.isVisiable = false;
                    this.transforList = [];
                    this.getList();
                }else{
                    this.message.error(res.errMsg);
                }
            }
        )
    }

}
